Config

Struct Config 

pub struct Config { /* private fields */ }
Configuration for the SQL backend

Implementations

Source

impl Config

pub fn new(queue: &str) -> Config

Create a new config with a jobs queue

pub fn with_poll_interval(self, strategy: MultiStrategy) -> Config

Interval between database poll queries

Defaults to 100ms

pub fn set_keep_alive(self, keep_alive: Duration) -> Config

Interval between worker keep-alive database updates

Defaults to 30s

pub fn set_buffer_size(self, buffer_size: usize) -> Config

Buffer size to use when querying for jobs

Defaults to 10

pub fn keep_alive(&self) -> &Duration

Gets a reference to the keep_alive duration.

pub fn keep_alive_mut(&mut self) -> &mut Duration

Gets a mutable reference to the keep_alive duration.

pub fn buffer_size(&self) -> usize

Gets the buffer size.

pub fn poll_strategy(&self) -> &MultiStrategy

Gets a reference to the poll_strategy.

pub fn poll_strategy_mut(&mut self) -> &mut MultiStrategy

Gets a mutable reference to the poll_strategy.

pub fn queue(&self) -> &Queue

Gets a reference to the queue.

pub fn queue_mut(&mut self) -> &mut Queue

Gets a mutable reference to the queue.

pub fn reenqueue_orphaned_after(&self) -> Duration

Gets the reenqueue_orphaned_after duration.

pub fn reenqueue_orphaned_after_mut(&mut self) -> &mut Duration

Gets a mutable reference to the reenqueue_orphaned_after.

pub fn set_reenqueue_orphaned_after(self, after: Duration) -> Config

Occasionally some workers die, or abandon jobs because of panics. This is the time a task takes before its back to the queue

Defaults to 5 minutes

pub fn ack(&self) -> bool

Whether to automatically acknowledge jobs after processing Defaults to true

pub fn set_ack(self, auto_ack: bool) -> Config

Set whether to automatically acknowledge jobs after processing