pub struct Config { /* private fields */ }Expand description
Configuration for the SQL backend
Implementations
Sourceimpl Config
impl Config
Sourcepub fn with_poll_interval(self, strategy: MultiStrategy) -> Config
pub fn with_poll_interval(self, strategy: MultiStrategy) -> Config
Interval between database poll queries
Defaults to 100ms
Sourcepub fn set_keep_alive(self, keep_alive: Duration) -> Config
pub fn set_keep_alive(self, keep_alive: Duration) -> Config
Interval between worker keep-alive database updates
Defaults to 30s
Sourcepub fn set_buffer_size(self, buffer_size: usize) -> Config
pub fn set_buffer_size(self, buffer_size: usize) -> Config
Buffer size to use when querying for jobs
Defaults to 10
Sourcepub fn keep_alive(&self) -> &Duration
pub fn keep_alive(&self) -> &Duration
Gets a reference to the keep_alive duration.
Sourcepub fn keep_alive_mut(&mut self) -> &mut Duration
pub fn keep_alive_mut(&mut self) -> &mut Duration
Gets a mutable reference to the keep_alive duration.
Sourcepub fn buffer_size(&self) -> usize
pub fn buffer_size(&self) -> usize
Gets the buffer size.
Sourcepub fn poll_strategy(&self) -> &MultiStrategy
pub fn poll_strategy(&self) -> &MultiStrategy
Gets a reference to the poll_strategy.
Sourcepub fn poll_strategy_mut(&mut self) -> &mut MultiStrategy
pub fn poll_strategy_mut(&mut self) -> &mut MultiStrategy
Gets a mutable reference to the poll_strategy.
Sourcepub fn reenqueue_orphaned_after(&self) -> Duration
pub fn reenqueue_orphaned_after(&self) -> Duration
Gets the reenqueue_orphaned_after duration.
Sourcepub fn reenqueue_orphaned_after_mut(&mut self) -> &mut Duration
pub fn reenqueue_orphaned_after_mut(&mut self) -> &mut Duration
Gets a mutable reference to the reenqueue_orphaned_after.
Sourcepub fn set_reenqueue_orphaned_after(self, after: Duration) -> Config
pub fn set_reenqueue_orphaned_after(self, after: Duration) -> Config
Occasionally some workers die, or abandon jobs because of panics. This is the time a task takes before its back to the queue
Defaults to 5 minutes