pub struct PgMiddleware { /* private fields */ }Expand description
Middleware layer used by the PostgreSQL backend.
The lock step always runs. The acknowledge step is installed only when the queue config has automatic acknowledgement enabled.
Implementations
Sourceimpl PgMiddleware
impl PgMiddleware
Sourcepub fn with_lease_token(
pool: PgPool,
auto_ack: bool,
lease_token: Arc<str>,
) -> Self
pub fn with_lease_token( pool: PgPool, auto_ack: bool, lease_token: Arc<str>, ) -> Self
Create the PostgreSQL backend middleware with lease-token binding for
the auto-ack path. Used by crate::PostgresStorage so completed jobs
can only be acknowledged by a worker possessing the per-storage token.